@@ -1,5 +1,5 @@
 /*
- *  tree/src/grow.c by B. D. Ripley  Copyright (C) 1994-2012
+ *  tree/src/grow.c by B. D. Ripley  Copyright (C) 1994-2016
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,6 +15,9 @@
  *  http://www.r-project.org/Licenses/
  */
 
+#include <stddef.h>
+#include <math.h>
+#include <string.h>
 #include <stdio.h>
 #include <R.h>
 
